@@ -30,6 +30,9 @@ function (
 	, y_free = FALSE
 	, print_code = FALSE
 ){
+	if(inherits(data, "tbl_df")) {
+		data <- as.data.frame(data)
+	}
 	args_to_check = c('dv','wid','within','between','within_full','between_full','diff','x','split','row','col','to_numeric','within_covariates','between_covariates')
 	args = as.list(match.call()[-1])
 	for(i in 1:length(args)){
@@ -125,7 +128,7 @@ function (
 		if(!is.null(row)){
 			stop('You may not specify a variable to "row" when also specifying multiple dvs.')
 		}
-		if(is.data.frame(data)|(length(dv)!=length(data))){		
+		if(is.data.frame(data)|(length(dv)!=length(data))){
 			stop('When specifying multiple dvs, you must provide a list to "data" with as many elements as there are dvs..')
 		}
 		row = .(dv)
@@ -179,7 +182,7 @@ function (
 			if(!is.null(dv_labs)){
 				stats$dv = factor(stats$dv, levels = dv_levs, labels = dv_labs)
 			}else{
-				stats$dv = factor(stats$dv, levels = dv_levs)				
+				stats$dv = factor(stats$dv, levels = dv_levs)
 			}
 		}else{
 			 if(!is.null(dv_labs)){
@@ -215,7 +218,7 @@ function (
 			p = paste(p,"+\ngeom_line(\n\tmapping = aes(\n\t\tcolour = ",split,"\n\t\t, linetype = ",split,"\n\t\t, x = I(as.numeric(",x,"))\n\t)\n\t, alpha = .8\n)",sep='')
 		}
 		if(do_bars){
-			p = paste(p,"+\ngeom_errorbar(\n\tmapping = aes(\n\t\tcolour = ",split,"\n\t\t, ymin = lo\n\t\t, ymax = hi\n\t)\n\t, linetype = 1\n\t, show_guide = FALSE\n\t, width = ",bar_width,"\n\t, alpha = .5\n)",sep='')
+			p = paste(p,"+\ngeom_errorbar(\n\tmapping = aes(\n\t\tcolour = ",split,"\n\t\t, ymin = lo\n\t\t, ymax = hi\n\t)\n\t, linetype = 1\n\t, show.legend = FALSE\n\t, width = ",bar_width,"\n\t, alpha = .5\n)",sep='')
 		}
 	}else{
 		p = paste(p,"+\ngeom_point()",sep='')
@@ -223,7 +226,7 @@ function (
 			p = paste(p,"+\ngeom_line(\n\tmapping = aes(\n\t\tx = I(as.numeric(",x,"))\n\t)\n)",sep='')
 		}
 		if(do_bars){
-			p = paste(p,"+\ngeom_errorbar(\n\tmapping = aes(\n\t\tymin = lo\n\t\t, ymax = hi\n\t)\n\t, linetype = 1\n\t, show_guide = FALSE\n\t, width = ",bar_width,"\n\t, alpha = .5\n)",sep='')
+			p = paste(p,"+\ngeom_errorbar(\n\tmapping = aes(\n\t\tymin = lo\n\t\t, ymax = hi\n\t)\n\t, linetype = 1\n\t, show.legend = FALSE\n\t, width = ",bar_width,"\n\t, alpha = .5\n)",sep='')
 		}
 	}
 	if(!is.null(row)){
@@ -288,4 +291,3 @@ function (
 		return(eval(parse(text=p)))
 	}
 }
-
